"""
This script shows how to get log details of the shielding in progress
You must use the UUID obtained with the start_shielding_script.py as inout for the 'shieldingUUID'
- shieldingUUID: The identifier of the shielding process
In this script you can see how the endpoints are used in order to:
    1. Obtain authorization
    2. Obtain logs of the shielding in progress
"""
import argparse
import os
import requests
from requests.auth import HTTPBasicAuth
from dotenv import load_dotenv


load_dotenv(override=False)


def get_env_var(env_var_name: str):
    env_var_value = os.getenv(env_var_name, '')
    if not env_var_value.strip():
        raise Exception(f"Missing environment variable required: {env_var_name}")
    return env_var_value


client_id = get_env_var('SHIELDINGAPPS_CLIENT_ID')
client_secret = get_env_var('SHIELDINGAPPS_CLIENT_SECRET')
auth_server_url = get_env_var('SHIELDINGAPPS_AUTH_SERVER_URL')
print(f"Variable Environment [SHIELDINGAPPS_AUTH_SERVER_URL]={auth_server_url}")
base_shieldingapps_api_url = get_env_var('SHIELDINGAPPS_BASE_SHIELDINGAPPS_API_URL')
print(f"Variable Environment [SHIELDINGAPPS_BASE_SHIELDINGAPPS_API_URL]={base_shieldingapps_api_url}")


def log_details_shielding_app(shielding_uuid: str):
    print("### Starting Shielding Log Details...")

    payload = 'grant_type=client_credentials'
    headers = {'Content-Type': 'application/x-www-form-urlencoded'}
    response = requests.request("POST", auth_server_url, headers=headers, data=payload,
                                auth=HTTPBasicAuth(client_id, client_secret))
    if not response.status_code == 200:
        print(f"Response-status_code: {response.status_code} - [{response.text}]")
        raise Exception("Error when trying to get authorization!!!")

    access_token = response.json().get('access_token')

    # 8. After shielding is started, shielding progress can be obtained via Shielding Progress REST API (Optional step)
    progress_shieldingapps_api_url = f"{base_shieldingapps_api_url}?uuid={shielding_uuid}&action=progress"

    headers = {'Authorization': f"Bearer {access_token}"} # Access token obtained in step 4.
    response_progress = requests.request("GET", progress_shieldingapps_api_url, headers=headers)

    if response_progress.status_code == 200:
        print(f"Response: {response_progress.json()}")  # Shielding progress details
    else:
        print(f"Response-status_code: {response_progress.status_code} - [{response_progress.text}]")
        raise Exception("Something went wrong when trying to get App shielding progress!!")

    print("### Shielding Log Details Finished!")
    return response_progress


def main():
    parser = argparse.ArgumentParser(description="Download shielded mobile application.")
    parser.add_argument('--shieldingUUID', type=str, required=True,
                        help="The UUID reference of the shielding process.")
    args = parser.parse_args()
    log_details_shielding_app(args.shieldingUUID)


if __name__ == "__main__":
    main()
